fields property

Iterable<Field>? get fields

A set of fields bound to the logging context.

May be omitted if no fields are bound to the logging context.

Implementation

Iterable<Field>? get fields;