name property
String?
get
name
Name of the logger this record originally emitted by.
If the logger has no name, may be omitted.
Implementation
String? get name;
Name of the logger this record originally emitted by.
If the logger has no name, may be omitted.
String? get name;